@@ -10,9 +10,9 @@ def default_cache_func(
         redis_model,
         save_related_models,
         get_or_create_redis_model_from_django_model,
-    exclude_fields,
+        exclude_fields,
+        filter_by,
 ):
-
     redis_dicts = redis_root.get(redis_model, return_dict=True)
     # cache_to_django(
     #     django_model,
@@ -25,7 +25,8 @@ def default_cache_func(
         redis_root,
         save_related_models,
         get_or_create_redis_model_from_django_model,
-    exclude_fields,
+        exclude_fields,
+        filter_by,
     )
 
 
@@ -138,16 +139,19 @@ def update_django_many_to_many(
                 param.add(obj)
 
 
-async def django_sync_to_async_list(
+@sync_to_async
+def django_sync_to_async_list(
         django_func,
         params_to_use=None,
 ):
     if params_to_use is None:
-        params_to_use = {}
-    django_instances_qs = await sync_to_async(django_func)(**params_to_use)
-    django_instances_iter = await sync_to_async(django_instances_qs.__iter__)()
-    django_instances = list(django_instances_iter)
-    return django_instances
+        result_qs = django_func()
+    else:
+        result_qs = django_func(**params_to_use)
+
+    result = list(result_qs)
+
+    return result
 
 
 @sync_to_async
@@ -166,6 +170,7 @@ def django_to_cache(
         save_related_models,
         get_or_create_redis_model_from_django_model,
         exclude_fields,
+        filter_by,
 ):
     async def run_django_to_cache(
             django_model,
@@ -174,8 +179,15 @@ def django_to_cache(
             save_related_models,
             get_or_create_redis_model_from_django_model,
             exclude_fields,
+            filter_by,
     ):
-        django_instances = await django_sync_to_async_list(django_model.objects.all)
+        if filter_by.keys():
+            if django_model in filter_by.keys():
+                django_instances = await django_sync_to_async_list(django_model.objects.filter, filter_by[django_model])
+            else:
+                django_instances = await django_sync_to_async_list(django_model.objects.all)
+        else:
+            django_instances = await django_sync_to_async_list(django_model.objects.all)
         async_chunk_size = redis_root.async_db_requests_limit
         async_tasks = []
         completed = 0
@@ -207,6 +219,7 @@ def django_to_cache(
             save_related_models,
             get_or_create_redis_model_from_django_model,
             exclude_fields,
+            filter_by,
         )
     )
 
@@ -235,6 +248,7 @@ async def update_or_create_redis_instance_from_django_instance(
             django_id=django_instance.id,
             **fields_to_create
         ).save()
+        print(redis_model.__name__, redis_instance['django_id'])
         result_redis_instance_id = redis_instance['id']
         print(f'{redis_model} with django_id={django_instance.id} created...')
     else:
@@ -283,7 +297,6 @@ async def django_instance_field_to_redis_value(
             django_foreign_key_instance = django_field_value
 
             if save_related_models:
-                print(1)
                 redis_foreign_key_instance = await get_or_create_redis_instance_from_django_instance(
                     django_foreign_key_instance,
                     redis_root,
@@ -297,7 +310,6 @@ async def django_instance_field_to_redis_value(
     elif django_field.__class__ == django_models.ManyToManyField:
         django_many_to_many_instances = await django_sync_to_async_list(django_field_value.all)
         if save_related_models:
-            print(len(django_many_to_many_instances))
             redis_value = [
                 await get_or_create_redis_instance_from_django_instance(
                     django_many_to_many_instance,
