@@ -456,6 +456,10 @@ class RedisRoot:
             django_model: cache_conf['exclude_fields']
             for django_model, cache_conf in django_models_to_cache.items()
         }
+        filter_by = {
+            django_model: cache_conf['filter_by']
+            for django_model, cache_conf in django_models_to_cache.items()
+        }
         for django_model, cache_conf in django_models_to_cache.items():
             cache_func = cache_conf['cache_func']
             save_related_models = cache_conf['save_related_models']
@@ -587,6 +591,7 @@ class RedisRoot:
                 save_related_models,
                 get_or_create_redis_model_from_django_model,
                 exclude_fields,
+                filter_by,
             )
             print(f'Cached {django_model}')
 
@@ -634,7 +639,8 @@ class RedisRoot:
             'ttl': 60 * 5,
             'save_related_models': True,
             'cache_func': default_cache_func,
-            'exclude_fields': []
+            'exclude_fields': [],
+            'filter_by': {},
         }
         if user_cache_conf is not None:
             if type(user_cache_conf) == dict:
@@ -670,6 +676,17 @@ class RedisRoot:
                             raise Exception(f'{name} -> cache config -> exclude_fields -> all fields must be strings')
                     else:
                         raise Exception(f'{name} -> cache config -> exclude_fields must be list')
+                if 'filter_by' in user_cache_conf.keys():
+                    if type(user_cache_conf['filter_by']) == dict:
+                        if all([
+                            (type(field_name) == str)
+                            for field_name in user_cache_conf['filter_by'].keys()
+                        ]):
+                            cache_conf['filter_by'] = user_cache_conf['filter_by']
+                        else:
+                            raise Exception(f'{name} -> cache config -> filter_by -> all keys must be strings')
+                    else:
+                        raise Exception(f'{name} -> cache config -> filter_by must be dict')
             else:
                 raise Exception(f'{name} -> cache config must be dict')
 
